==> nextcloud-13.0.1.tgz: nextcloud/apps/files/l10n/sv.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Lagring är tillfälligt inte tillgänglig",
    "Storage invalid" : "Lagring ogiltig",
    "Unknown error" : "Okänt fel",
    "All files" : "Alla filer",
    "Recent" : "Senaste",
    "File could not be found" : "Fil kunde inte hittas",
    "Home" : "Hem",
    "Close" : "Stäng",
    "Favorites" : "Favoriter",
    "Could not create folder \"{dir}\"" : "Kunde inte skapa mapp \"{dir}\"",
    "Upload cancelled." : "Uppladdning avbruten.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Kan inte ladda upp {filename} eftersom den antingen är en mapp eller har 0 bytes.",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Inte tillräckligt med ledigt utrymme, du laddar upp {size1} men endast {size2} finns kvar.",
    "Target folder \"{dir}\" does not exist any more" : "Målmapp \"{dir}\" existerar inte mer",
    "Not enough free space" : "Inte tillräckligt med ledigt utrymme",
    "Uploading …" : "Laddar upp ..",
    "…" : "...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} av {totalSize} ({bitrate})",
    "Target folder does not exist any more" : "Målmapp existerar inte längre",
    "Error when assembling chunks, status code {status}" : "Fel vid ihopsättning av bitarna: statuskod:  {status}",
    "Actions" : "Åtgärder",
    "Download" : "Ladda ned",
    "Rename" : "Byt namn",
    "Move or copy" : "Flytta eller kopiera",
    "Target folder" : "Målmapp",
    "Delete" : "Radera",
    "Disconnect storage" : "Koppla bort lagring",
    "Unshare" : "Sluta dela",
    "Could not load info for file \"{file}\"" : "Kunde inte ladda information för fil \"{file}\"",
    "Files" : "Filer",
    "Details" : "Detaljer",
    "Select" : "Välj",
    "Pending" : "Väntar",
    "Unable to determine date" : "Misslyckades avgöra datum",
    "This operation is forbidden" : "Denna operation är förbjuden",
    "This directory is unavailable, please check the logs or contact the administrator" : "Denna katalog är inte tillgänglig, kontrollera loggarna eller kontakta administratören",
    "Could not move \"{file}\", target exists" : "Kunde inte flytta \"{file}\", filen existerar redan",
    "Could not move \"{file}\"" : "Kunde inte flytta \"{file}\"",
    "Could not copy \"{file}\", target exists" : "Kunde inte kopiera \"{file}\", filen existerar redan",
    "Could not copy \"{file}\"" : "Kunde inte kopiera \"{file}\"",
    "Copied {origin} inside {destination}" : "Kopierade {origin} till {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "Kopierade {origin} och {nbfiles} andra filer i {destination}",
    "{newName} already exists" : "{newName} existerar redan",
    "Could not rename \"{fileName}\", it does not exist any more" : "Kunde inte döpa om \"{fileName}\", filen existerar inte mer",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Namnet \"{targetName}\" används redan i mappen \"{dir}\". Vänligen välj ett annat namn.",
    "Could not rename \"{fileName}\"" : "Kan inte döpa om \"{fileName}\"",
    "Could not create file \"{file}\"" : "Kunde inte skapa fil \"{fileName}\"",
    "Could not create file \"{file}\" because it already exists" : "Kunde inte skapa fil \"{file}\" därför att den redan existerar",
    "Could not create folder \"{dir}\" because it already exists" : "Kunde inte skapa \"{dir}\" därför att den redan existerar",
    "Error deleting file \"{fileName}\"." : "Fel när \"{fileName}\" skulle raderas.",
    "No search results in other folders for {tag}{filter}{endtag}" : "Inga sökresultat i andra mappar för {tag}{filter}{endtag}",
    "Name" : "Namn",
    "Size" : "Storlek",
    "Modified" : "Ändrad",
    "_%n folder_::_%n folders_" : ["%n mapp","%n mappar"],
    "_%n file_::_%n files_" : ["%n fil","%n filer"],
    "{dirs} and {files}" : "{dirs} och {files}",
    "_including %n hidden_::_including %n hidden_" : ["inkluderar %n gömd","inkluderar %n gömda"],
    "You don’t have permission to upload or create files here" : "Du har ej tillåtelse att ladda upp eller skapa filer här",
    "_Uploading %n file_::_Uploading %n files_" : ["Laddar upp %n fil","Laddar upp %n filer"],
    "New" : "Ny",
    "{used} of {quota} used" : "{used} av {quota} använt",
    "{used} used" : "{used} använt",
    "\"{name}\" is an invalid file name." : "\"{name}\" är ett ogiltigt filnamn.",
    "File name cannot be empty." : "Filnamn kan inte vara tomt.",
    "\"/\" is not allowed inside a file name." : "\"/\" är inte tillåtet i ett filnamn.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" är inte en tillåten filtyp",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Lagring av {owner}  är full, filer kan inte uppdateras eller synkroniseras längre!",
    "Your storage is full, files can not be updated or synced anymore!" : "Ditt lagringsutrymme är fullt, filer kan inte längre uppdateras eller synkroniseras!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Lagring av  {owner}  är nästan full  ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Ditt lagringsutrymme är nästan fullt ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["matchar '{filter}'","matcha '{filter}'"],
    "View in folder" : "Utforska i mapp",
    "Copied!" : "Kopierad!",
    "Copy direct link (only works for users who have access to this file/folder)" : "Kopiera direktlänk (fungerar endast för de användare som har tillgång till denna fil eller mapp)",
    "Path" : "sökväg",
    "_%n byte_::_%n bytes_" : ["%n bytes","%n bytes"],
    "Favorited" : "Favoriserad",
    "Favorite" : "Favorit",
    "New folder" : "Ny mapp",
    "Upload file" : "Ladda upp fil",
    "Not favorited" : "Ej favoriserade",
    "Remove from favorites" : "Ta bort från favoriter",
    "Add to favorites" : "Lägg till i favoriter",
    "An error occurred while trying to update the tags" : "Ett fel uppstod när uppdatera taggarna",
    "Added to favorites" : "Lades till i favoriter",
    "Removed from favorites" : "Togs bort från favoriter",
    "You added {file} to your favorites" : "Du la till {file} till dina favoriter",
    "You removed {file} from your favorites" : "Du tog bort {file} från dina favoriter",
    "File changes" : "Filändringar",
    "Created by {user}" : "Skapad av {user}",
    "Changed by {user}" : "Ändrad av {user}",
    "Deleted by {user}" : "Raderad av {user}",
    "Restored by {user}" : "Återställd av {user}",
    "Renamed by {user}" : "Filnamn ändrat av {user}",
    "Moved by {user}" : "Flyttad av {user}",
    "\"remote user\"" : "\"extern användare\"",
    "You created {file}" : "Du skapade {file}",
    "{user} created {file}" : "{user} skapade {file}",
    "{file} was created in a public folder" : "{file} skapades i en offentlig mapp",
    "You changed {file}" : "Du ändrade {file}",
    "{user} changed {file}" : "{user} ändrade {file}",
    "You deleted {file}" : "Du raderade {file}",
    "{user} deleted {file}" : "{user} raderade {file}",
    "You restored {file}" : "Du återställde {file}",
    "{user} restored {file}" : "{user} återställde {file}",
    "You renamed {oldfile} to {newfile}" : "Du ändrade filnamn {oldfile} till {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "{user} ändrade filnamn {oldfile} till {newfile}",
    "You moved {oldfile} to {newfile}" : "Du flyttade {oldfile} till {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} flyttade {oldfile} till {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "En fil har lagts till eller tagits bort från dina <strong>favoriter</strong>",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "En fil har blivit <strong>ändrad</strong> eller <strong>bytt namn</strong>",
    "A new file or folder has been <strong>created</strong>" : "En ny fil eller mapp har blivit <strong>skapad</strong>",
    "A file or folder has been <strong>deleted</strong>" : "En fil eller mapp har <strong>tagits bort</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Begränsa notiser om skapande och ändringar till dina <strong>favoritfiler</strong> <em>(Endast i flödet)</em>",
    "A file or folder has been <strong>restored</strong>" : "En fil eller mapp har <strong>återställts</strong>",
    "Unlimited" : "Obegränsad",
    "Upload (max. %s)" : "Ladda upp (max. %s)",
    "File handling" : "Filhantering",
    "Maximum upload size" : "Maximal storlek att ladda upp",
    "max. possible: " : "max. möjligt:",
    "Save" : "Spara",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Med PHP-FPM kan det ta cirka 5 minuter för ändringarna att träda i kraft.",
    "Missing permissions to edit from here." : "Saknar rättigheter att ändra härifrån.",
    "%s of %s used" : "%s av %s använt",
    "%s used" : "%s använt",
    "Settings" : "Inställningar",
    "Show hidden files" : "Visa dolda filer",
    "WebDAV" : "WebDAV",
    "Cancel upload" : "Avbryt uppladdning",
    "No files in here" : "Inga filer kunde hittas",
    "Upload some content or sync with your devices!" : "Ladda upp innehåll eller synkronisera med dina enheter!",
    "No entries found in this folder" : "Inget innehåll hittades i denna mapp",
    "Select all" : "Välj allt",
    "Upload too large" : "För stor uppladdning",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Filerna du försöker ladda upp överstiger den maximala storleken för filöverföringar på servern.",
    "No favorites yet" : "Inga favoriter ännu",
    "Files and folders you mark as favorite will show up here" : "Filer och mappar markerade som favoriter kommer att visas här",
    "Shared with you" : "Delad med dig",
    "Shared with others" : "Delad med andra",
    "Shared by link" : "Delad via länk",
    "Tags" : "Taggar",
    "Deleted files" : "Raderade filer",
    "Text file" : "Textfil",
    "New text file.txt" : "nytextfil.txt"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-14.0.1.tgz: nextcloud/apps/files/l10n/sv.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Lagring är tillfälligt inte tillgänglig",
    "Storage invalid" : "Lagring ogiltig",
    "Unknown error" : "Okänt fel",
    "All files" : "Alla filer",
    "Recent" : "Senaste",
    "Favorites" : "Favoriter",
    "File could not be found" : "Fil kunde inte hittas",
    "Move or copy" : "Flytta eller kopiera",
    "Download" : "Ladda ned",
    "Delete" : "Radera",
    "Home" : "Hem",
    "Close" : "Stäng",
    "Could not create folder \"{dir}\"" : "Kunde inte skapa mapp \"{dir}\"",
    "Upload cancelled." : "Uppladdning avbruten.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Kan inte ladda upp {filename} eftersom den antingen är en mapp eller har 0 bytes.",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Inte tillräckligt med ledigt utrymme, du laddar upp {size1} men endast {size2} finns kvar.",
    "Target folder \"{dir}\" does not exist any more" : "Målmapp \"{dir}\" existerar inte mer",
    "Not enough free space" : "Inte tillräckligt med ledigt utrymme",
    "Uploading …" : "Laddar upp ..",
    "…" : "...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} av {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "Uppladdning av det här objektet stöds inte",
    "Target folder does not exist any more" : "Målmapp existerar inte längre",
    "Error when assembling chunks, status code {status}" : "Fel vid ihopsättning av bitarna: statuskod:  {status}",
    "Actions" : "Åtgärder",
    "Rename" : "Byt namn",
    "Copy" : "Kopiera",
    "Target folder" : "Målmapp",
    "Disconnect storage" : "Koppla bort lagring",
    "Unshare" : "Sluta dela",
    "Could not load info for file \"{file}\"" : "Kunde inte ladda information för fil \"{file}\"",
    "Files" : "Filer",
    "Details" : "Detaljer",
    "Select" : "Välj",
    "Pending" : "Väntar",
    "Unable to determine date" : "Misslyckades avgöra datum",
    "This operation is forbidden" : "Denna operation är förbjuden",
    "This directory is unavailable, please check the logs or contact the administrator" : "Denna katalog är inte tillgänglig, kontrollera loggarna eller kontakta administratören",
    "Could not move \"{file}\", target exists" : "Kunde inte flytta \"{file}\", filen existerar redan",
    "Could not move \"{file}\"" : "Kunde inte flytta \"{file}\"",
    "Could not copy \"{file}\", target exists" : "Kunde inte kopiera \"{file}\", filen existerar redan",
    "Could not copy \"{file}\"" : "Kunde inte kopiera \"{file}\"",
    "Copied {origin} inside {destination}" : "Kopierade {origin} till {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "Kopierade {origin} och {nbfiles} andra filer i {destination}",
    "{newName} already exists" : "{newName} existerar redan",
    "Could not rename \"{fileName}\", it does not exist any more" : "Kunde inte döpa om \"{fileName}\", filen existerar inte mer",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Namnet \"{targetName}\" används redan i mappen \"{dir}\". Vänligen välj ett annat namn.",
    "Could not rename \"{fileName}\"" : "Kan inte döpa om \"{fileName}\"",
    "Could not create file \"{file}\"" : "Kunde inte skapa fil \"{fileName}\"",
    "Could not create file \"{file}\" because it already exists" : "Kunde inte skapa fil \"{file}\" därför att den redan existerar",
    "Could not create folder \"{dir}\" because it already exists" : "Kunde inte skapa \"{dir}\" därför att den redan existerar",
    "Error deleting file \"{fileName}\"." : "Fel när \"{fileName}\" skulle raderas.",
    "No search results in other folders for {tag}{filter}{endtag}" : "Inga sökresultat i andra mappar för {tag}{filter}{endtag}",
    "Name" : "Namn",
    "Size" : "Storlek",
    "Modified" : "Ändrad",
    "_%n folder_::_%n folders_" : ["%n mapp","%n mappar"],
    "_%n file_::_%n files_" : ["%n fil","%n filer"],
    "{dirs} and {files}" : "{dirs} och {files}",
    "_including %n hidden_::_including %n hidden_" : ["inkluderar %n gömd","inkluderar %n gömda"],
    "You don’t have permission to upload or create files here" : "Du har ej tillåtelse att ladda upp eller skapa filer här",
    "_Uploading %n file_::_Uploading %n files_" : ["Laddar upp %n fil","Laddar upp %n filer"],
    "New" : "Ny",
    "{used} of {quota} used" : "{used} av {quota} använt",
    "{used} used" : "{used} använt",
    "\"{name}\" is an invalid file name." : "\"{name}\" är ett ogiltigt filnamn.",
    "File name cannot be empty." : "Filnamn kan inte vara tomt.",
    "\"/\" is not allowed inside a file name." : "\"/\" är inte tillåtet i ett filnamn.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" är inte en tillåten filtyp",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Lagring av {owner}  är full, filer kan inte uppdateras eller synkroniseras längre!",
    "Your storage is full, files can not be updated or synced anymore!" : "Ditt lagringsutrymme är fullt, filer kan inte längre uppdateras eller synkroniseras!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Lagring av  {owner}  är nästan full  ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Ditt lagringsutrymme är nästan fullt ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["matchar '{filter}'","matcha '{filter}'"],
    "View in folder" : "Utforska i mapp",
    "Copied!" : "Kopierad!",
    "Copy direct link (only works for users who have access to this file/folder)" : "Kopiera direktlänk (fungerar endast för de användare som har tillgång till denna fil eller mapp)",
    "Path" : "sökväg",
    "_%n byte_::_%n bytes_" : ["%n bytes","%n bytes"],
    "Favorited" : "Favoriserad",
    "Favorite" : "Favorit",
    "New folder" : "Ny mapp",
    "Upload file" : "Ladda upp fil",
    "Not favorited" : "Ej favoriserade",
    "Remove from favorites" : "Ta bort från favoriter",
    "Add to favorites" : "Lägg till i favoriter",
    "An error occurred while trying to update the tags" : "Ett fel uppstod när uppdatera taggarna",
    "Added to favorites" : "Lades till i favoriter",
    "Removed from favorites" : "Togs bort från favoriter",
    "You added {file} to your favorites" : "Du la till {file} till dina favoriter",
    "You removed {file} from your favorites" : "Du tog bort {file} från dina favoriter",
    "File changes" : "Filändringar",
    "Created by {user}" : "Skapad av {user}",
    "Changed by {user}" : "Ändrad av {user}",
    "Deleted by {user}" : "Raderad av {user}",
    "Restored by {user}" : "Återställd av {user}",
    "Renamed by {user}" : "Filnamn ändrat av {user}",
    "Moved by {user}" : "Flyttad av {user}",
    "\"remote user\"" : "\"extern användare\"",
    "You created {file}" : "Du skapade {file}",
    "You created an encrypted file in {file}" : "Du skapade en krypterad fil i {file}",
    "{user} created {file}" : "{user} skapade {file}",
    "{user} created an encrypted file in {file}" : "{user} skapade en krypterad fil i {file}",
    "{file} was created in a public folder" : "{file} skapades i en offentlig mapp",
    "You changed {file}" : "Du ändrade {file}",
    "You changed an encrypted file in {file}" : "Du ändrade en krypterad fil i {file}",
    "{user} changed {file}" : "{user} ändrade {file}",
    "{user} changed an encrypted file in {file}" : "{user} ändrade en krypterad fil i {file}",
    "You deleted {file}" : "Du raderade {file}",
    "You deleted an encrypted file in {file}" : "Du raderade en krypterad fil i {file}",
    "{user} deleted {file}" : "{user} raderade {file}",
    "{user} deleted an encrypted file in {file}" : "{user} raderade en krypterad fil i {file}",
    "You restored {file}" : "Du återställde {file}",
    "{user} restored {file}" : "{user} återställde {file}",
    "You renamed {oldfile} to {newfile}" : "Du ändrade filnamn {oldfile} till {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "{user} ändrade filnamn {oldfile} till {newfile}",
    "You moved {oldfile} to {newfile}" : "Du flyttade {oldfile} till {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} flyttade {oldfile} till {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "En fil har lagts till eller tagits bort från dina <strong>favoriter</strong>",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "En fil har blivit <strong>ändrad</strong> eller <strong>bytt namn</strong>",
    "A new file or folder has been <strong>created</strong>" : "En ny fil eller mapp har blivit <strong>skapad</strong>",
    "A file or folder has been <strong>deleted</strong>" : "En fil eller mapp har <strong>tagits bort</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Begränsa notiser om skapande och ändringar till dina <strong>favoritfiler</strong> <em>(Endast i flödet)</em>",
    "A file or folder has been <strong>restored</strong>" : "En fil eller mapp har <strong>återställts</strong>",
    "Unlimited" : "Obegränsad",
    "Upload (max. %s)" : "Ladda upp (max. %s)",
    "File Management" : "Filhantering",
    "File handling" : "Filhantering",
    "Maximum upload size" : "Maximal storlek att ladda upp",
    "max. possible: " : "max. möjligt:",
    "Save" : "Spara",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Med PHP-FPM kan det ta cirka 5 minuter för ändringarna att träda i kraft.",
    "Missing permissions to edit from here." : "Saknar rättigheter att ändra härifrån.",
    "%s of %s used" : "%s av %s använt",
    "%s used" : "%s använt",
    "Settings" : "Inställningar",
    "Show hidden files" : "Visa dolda filer",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">access your Files via WebDAV</a>" : "Använd denna adress för att <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">komma åt dina filer med WebDAV</a>",
    "Cancel upload" : "Avbryt uppladdning",
    "No files in here" : "Inga filer kunde hittas",
    "Upload some content or sync with your devices!" : "Ladda upp innehåll eller synkronisera med dina enheter!",
    "No entries found in this folder" : "Inget innehåll hittades i denna mapp",
    "Select all" : "Välj allt",
    "Upload too large" : "För stor uppladdning",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Filerna du försöker ladda upp överstiger den maximala storleken för filöverföringar på servern.",
    "No favorites yet" : "Inga favoriter ännu",
    "Files and folders you mark as favorite will show up here" : "Filer och mappar markerade som favoriter kommer att visas här",
    "Tags" : "Taggar",
    "Deleted files" : "Raderade filer",
    "Shares" : "Delningar",
    "Shared with others" : "Delad med andra",
    "Shared with you" : "Delad med dig",
    "Shared by link" : "Delad via länk",
    "Deleted shares" : "Raderade delningar",
    "Text file" : "Textfil",
    "New text file.txt" : "nytextfil.txt",
    "Move" : "Flytta",
    "A new file or folder has been <strong>deleted</strong>" : "En ny fil eller mapp har blivit <strong>raderad</strong>",
    "A new file or folder has been <strong>restored</strong>" : "En ny fil eller mapp har blivit <strong>återställd</strong>",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "Använd denna adress för att <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">komma åt dina filer med WebDAV</a>"
},
"nplurals=2; plural=(n != 1);");
